@@ -117,7 +117,7 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
 
         return super().__classcall__(cls, ct, c, t, base_ring, tuple(prefix))
 
-    def __init__(self, ct, c, t, base_ring, prefix):
+    def __init__(self, ct, c, t, base_ring, prefix) -> None:
         r"""
         Initialize ``self``.
 
@@ -161,7 +161,7 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         return (self.degree_on_basis(t), t[1].length(), t[1], str(t[0]), str(t[2]))
 
     @lazy_attribute
-    def _reflections(self):
+    def _reflections(self) -> dict:
         """
         A dictionary of reflections to a pair of the associated root
         and coroot.
@@ -205,7 +205,7 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
             ret += "c_L={} and c_S={}".format(*self._c)
         return ret + " and t={} over {}".format(self._t, self.base_ring())
 
-    def _repr_term(self, t):
+    def _repr_term(self, t) -> str:
         """
         Return a string representation of the term indexed by ``t``.
 
@@ -238,26 +238,26 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
             sage: list(R.algebra_generators())
             [a1, a2, s1, s2, ac1, ac2]
         """
-        keys = ['a'+str(i) for i in self._cartan_type.index_set()]
-        keys += ['s'+str(i) for i in self._cartan_type.index_set()]
-        keys += ['ac'+str(i) for i in self._cartan_type.index_set()]
+        keys = ['a' + str(i) for i in self._cartan_type.index_set()]
+        keys += ['s' + str(i) for i in self._cartan_type.index_set()]
+        keys += ['ac' + str(i) for i in self._cartan_type.index_set()]
 
         def gen_map(k):
             if k[0] == 's':
                 i = int(k[1:])
                 return self.monomial((self._hd.one(),
-                                       self._weyl.group_generators()[i],
-                                       self._h.one()))
+                                      self._weyl.group_generators()[i],
+                                      self._h.one()))
             if k[1] == 'c':
                 i = int(k[2:])
                 return self.monomial((self._hd.one(),
-                                       self._weyl.one(),
-                                       self._h.monoid_generators()[i]))
+                                      self._weyl.one(),
+                                      self._h.monoid_generators()[i]))
 
             i = int(k[1:])
             return self.monomial((self._hd.monoid_generators()[i],
-                                   self._weyl.one(),
-                                   self._h.one()))
+                                  self._weyl.one(),
+                                  self._h.one()))
         return Family(keys, gen_map)
 
     @cached_method
@@ -320,12 +320,12 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         I = self._cartan_type.index_set()
         P = PolynomialRing(R, 'x', len(I))
         G = P.gens()
-        gens_dict = {a:G[i] for i,a in enumerate(I)}
+        gens_dict = {a: G[i] for i, a in enumerate(I)}
         Q = RootSystem(self._cartan_type).root_lattice()
         alpha = Q.simple_roots()
         alphacheck = Q.simple_coroots()
 
-        def commute_w_hd(w, al): # al is given as a dictionary
+        def commute_w_hd(w, al):  # al is given as a dictionary
             ret = P.one()
             for k in al:
                 x = sum(c * gens_dict[i] for i, c in alpha[k].weyl_action(w))
@@ -351,15 +351,15 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
                 del dr[ir]
 
             # We now commute right roots past the left reflections: s Ra = Ra' s
-            cur = self._from_dict({(hd, s*right[1], right[2]): c * cc
-                                    for s,c in terms
-                                    for hd, cc in commute_w_hd(s, dr)})
+            cur = self._from_dict({(hd, s * right[1], right[2]): c * cc
+                                   for s, c in terms
+                                   for hd, cc in commute_w_hd(s, dr)})
             cur = self.monomial((left[0], left[1], self._h(dl))) * cur
 
             # Add back in the commuted h and hd elements
             rem = self.monomial((left[0], left[1], self._h(dl)))
-            rem = rem * self.monomial((self._hd({ir:1}), self._weyl.one(),
-                                        self._h({il:1})))
+            rem = rem * self.monomial((self._hd({ir: 1}), self._weyl.one(),
+                                       self._h({il: 1})))
             rem = rem * self.monomial((self._hd(dr), right[1], right[2]))
 
             return cur + rem
@@ -385,9 +385,9 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
 
         # Otherwise dr is non-trivial and we have La Ls Ra Rs Rac,
         #   so we must commute Ls Ra = Ra' Ls
-        w = left[1]*right[1]
+        w = left[1] * right[1]
         return self._from_dict({(left[0] * hd, w, right[2]): c
-                                 for hd, c in commute_w_hd(left[1], dr)})
+                                for hd, c in commute_w_hd(left[1], dr)})
 
     @cached_method
     def _product_coroot_root(self, i, j):
@@ -435,7 +435,7 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
             # p[0] is the root, p[1] is the coroot, p[2] the value c_s
             pr, pc, c = self._reflections[s]
             terms.append((s, c * R(ac.scalar(pr) * pc.scalar(al)
-                                    / pc.scalar(pr))))
+                                   / pc.scalar(pr))))
         return tuple(terms)
 
     def degree_on_basis(self, m):
@@ -468,8 +468,8 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
             1/6*I + 1/6*s1 + 1/6*s2 + 1/6*s2*s1 + 1/6*s1*s2 + 1/6*s1*s2*s1
         """
         coeff = self.base_ring()(~self._weyl.cardinality())
-        hd_one = self._hd.one() # root - a
-        h_one = self._h.one() # coroot - ac
+        hd_one = self._hd.one()  # root - a
+        h_one = self._h.one()  # coroot - ac
         return self._from_dict({(hd_one, w, h_one): coeff for w in self._weyl},
                                remove_zeros=False)
 
@@ -489,12 +489,13 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         G = self.algebra_generators()
         cm = ~CartanMatrix(self._cartan_type)
         n = len(I)
-        ac = [G['ac'+str(i)] for i in I]
-        la = [sum(cm[i,j]*G['a'+str(I[i])] for i in range(n)) for j in range(n)]
-        return self.sum(ac[i]*la[i] for i in range(n))
+        ac = [G['ac' + str(i)] for i in I]
+        la = [sum(cm[i, j] * G['a' + str(I[i])]
+                  for i in range(n)) for j in range(n)]
+        return self.sum(ac[i] * la[i] for i in range(n))
 
     @cached_method
-    def an_element(self):
+    def _an_element_(self):
         """
         Return an element of ``self``.
 
@@ -506,7 +507,7 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         """
         G = self.algebra_generators()
         i = str(self._cartan_type.index_set()[0])
-        return G['a'+i] + 2*G['s'+i] + 3*G['ac'+i]
+        return G['a' + i] + 2 * G['s' + i] + 3 * G['ac' + i]
 
     def some_elements(self):
         """
