@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.modules
 """
 Generic code for bases
 
@@ -56,7 +57,6 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
             'bases of Non-Commutative Symmetric Functions or Quasisymmetric functions over the Rational Field'
             sage: C
             Category of bases of Non-Commutative Symmetric Functions or Quasisymmetric functions over the Rational Field
-
         """
         return "bases of Non-Commutative Symmetric Functions or Quasisymmetric functions over the %s" % self.base().base_ring()
 
@@ -68,8 +68,8 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
             sage: QSym = QuasiSymmetricFunctions(QQ)
             sage: BasesOfQSymOrNCSF(QSym).super_categories()
             [Category of realizations of Quasisymmetric functions over the Rational Field,
-             Category of graded hopf algebras with basis over Rational Field,
-             Join of Category of realizations of hopf algebras over Rational Field
+             Category of graded Hopf algebras with basis over Rational Field,
+             Join of Category of realizations of Hopf algebras over Rational Field
               and Category of graded algebras over Rational Field
               and Category of graded coalgebras over Rational Field]
         """
@@ -131,9 +131,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
             r"""
             Return the empty composition.
 
-            OUTPUT:
-
-            - The empty composition.
+            OUTPUT: the empty composition
 
             EXAMPLES::
 
@@ -208,7 +206,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
 
             INPUT:
 
-            - ``n`` -- a positive integer
+            - ``n`` -- positive integer
 
             OUTPUT:
 
@@ -242,7 +240,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
             INPUT:
 
             - ``composition`` -- a composition
-            - ``conjugate`` -- (default: ``False``) a boolean
+            - ``conjugate`` -- boolean (default: ``False``)
 
             OUTPUT:
 
@@ -632,8 +630,8 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
 
             INPUT:
 
-            - ``basis`` -- A basis of the dual Hopf algebra
-            - ``degree`` -- a non-negative integer
+            - ``basis`` -- a basis of the dual Hopf algebra
+            - ``degree`` -- nonnegative integer
 
             OUTPUT:
 
@@ -796,7 +794,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
 
                 Generalize this to all graded vector spaces?
             """
-            return self.sum_of_terms([ (lam, (-1)**(sum(lam)%2) * a)
+            return self.sum_of_terms([ (lam, (-1)**(sum(lam) % 2) * a)
                                        for lam, a in self(element) ],
                                      distinct=True)
 
@@ -840,7 +838,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
 
                 Generalize this to all graded vector spaces?
             """
-            return self.parent().sum_of_terms([ (lam, (-1)**(sum(lam)%2) * a)
+            return self.parent().sum_of_terms([ (lam, (-1)**(sum(lam) % 2) * a)
                                                 for lam, a in self ],
                                               distinct=True)
 
@@ -856,9 +854,7 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
 
             - ``y`` -- an element of the dual Hopf algebra of ``self``
 
-            OUTPUT:
-
-            - The result of pairing ``self`` with ``y``.
+            OUTPUT: the result of pairing ``self`` with ``y``
 
             EXAMPLES::
 
@@ -877,7 +873,6 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
                 0
                 sage: L[1,1,1].duality_pairing(F[1,2])
                 1
-
             """
             return self.parent().duality_pairing(self, y)
 
@@ -892,11 +887,9 @@ class BasesOfQSymOrNCSF(Category_realization_of_parent):
             INPUT:
 
             - ``y`` -- an element of the dual Hopf algebra of ``self``
-            - ``side`` -- (Default='left') Either 'left' or 'right'
+            - ``side`` -- (default: ``'left'``) either ``'left'`` or ``'right'``
 
-            OUTPUT:
-
-            - The result of skewing ``self`` by ``y``, on the side ``side``
+            OUTPUT: the result of skewing ``self`` by ``y``, on the side ``side``
 
             EXAMPLES:
 
@@ -1007,13 +1000,11 @@ class AlgebraMorphism(ModuleMorphismByLinearity): # Find a better name
         - ``domain`` -- an algebra with a multiplicative basis
         - ``on_generators`` -- a function defined on the index set of the generators
         - ``codomain`` -- the codomain
-        - ``position`` -- integer; default is 0
-        - ``category`` -- a category; defaults to None
-        - ``anti`` -- a boolean; defaults to False
+        - ``position`` -- integer (default: 0)
+        - ``category`` -- a category (default: ``None``)
+        - ``anti`` -- boolean (default: ``False``)
 
-        OUTPUT:
-
-        - module morphism
+        OUTPUT: module morphism
 
         EXAMPLES:
 
@@ -1050,7 +1041,7 @@ class AlgebraMorphism(ModuleMorphismByLinearity): # Find a better name
             sage: f(2*Psi[[]] + 3 * Psi[1,3,2] + Psi[2,4] )
             2*Psi[] - 3*Psi[1, 3, 2] + Psi[2, 4]
             sage: f.category()
-            Category of endsets of hopf algebras over Rational Field and graded modules over Rational Field
+            Category of endsets of Hopf algebras over Rational Field and graded modules over Rational Field
 
         If ``anti`` is true, this returns an anti-algebra morphism::
 
@@ -1131,16 +1122,14 @@ class AlgebraMorphism(ModuleMorphismByLinearity): # Find a better name
 
     def _on_basis(self, c):
         r"""
-        Computes the image of this morphism on the basis element indexed by
+        Compute the image of this morphism on the basis element indexed by
         ``c``.
 
         INPUT:
 
         - ``c`` -- an iterable that spits out generators
 
-        OUTPUT:
-
-        - element of the codomain
+        OUTPUT: element of the codomain
 
         EXAMPLES::
 
@@ -1151,7 +1140,6 @@ class AlgebraMorphism(ModuleMorphismByLinearity): # Find a better name
             sage: f = AlgebraMorphism(Psi, lambda i : Phi[i,i], codomain=Phi)
             sage: f._on_basis([ 3, 2 ])
             Phi[3, 3, 2, 2]
-
         """
         if self._anti:
             c = reversed(c)
@@ -1160,7 +1148,7 @@ class AlgebraMorphism(ModuleMorphismByLinearity): # Find a better name
 
 class GradedModulesWithInternalProduct(Category_over_base_ring):
     r"""
-    Constructs the class of modules with internal product. This is used to give an internal
+    Construct the class of modules with internal product. This is used to give an internal
     product structure to the non-commutative symmetric functions.
 
     EXAMPLES::
@@ -1193,7 +1181,7 @@ class GradedModulesWithInternalProduct(Category_over_base_ring):
 
             INPUT:
 
-             - ``I``, ``J`` -- compositions indexing two elements of the basis of self
+            - ``I``, ``J`` -- compositions indexing two elements of the basis of self
 
             Returns the internal product of the corresponding basis elements.
             If this method is implemented, the internal product is defined from
@@ -1246,7 +1234,6 @@ class GradedModulesWithInternalProduct(Category_over_base_ring):
                 R[2]
                 sage: R.internal_product(R[2,2], R[1,2])
                 0
-
             """
             if self.internal_product_on_basis is not NotImplemented:
                 return self.module_morphism(
@@ -1425,9 +1412,7 @@ class GradedModulesWithInternalProduct(Category_over_base_ring):
                 - ``left`` -- an element of the non-commutative symmetric functions
                 - ``right`` -- an element of the non-commutative symmetric functions
 
-                OUTPUT:
-
-                - The internal product of ``left`` and ``right``.
+                OUTPUT: the internal product of ``left`` and ``right``
 
                 EXAMPLES::
 
