@@ -241,12 +241,26 @@ class FreeMonoid(Monoid_class, UniqueRepresentation):
 
             sage: F(F(w), check=False)
             a^2*b^2*c*a*b*a*c
+
+            sage: F = FreeMonoid(3, 'a,b,c')
+            sage: G = FreeMonoid(2, 'a,c')
+            sage: F(G(Word("ac")))
+            a*c
         """
         # There should really be some careful type checking here...
-        if isinstance(x, FreeMonoidElement) and x.parent() is self:
-            return x
-        if isinstance(x, FreeMonoidElement) and x.parent() == self:
-            return self.element_class(self, x._element_list, check)
+        if isinstance(x, FreeMonoidElement):
+            P = x.parent()
+            if P is self:
+                return x
+            elif P == self:
+                return self.element_class(self, x._element_list, check)
+            elif all(v in self.variable_names()
+                     for v in P.variable_names()):
+                reindex = [next(j for j, w in enumerate(self.variable_names())
+                                if v == w)
+                           for v in P.variable_names()]
+                elt = [(reindex[i], exp) for i, exp in x._element_list]
+                return self.element_class(self, elt, check)
         if isinstance(x, (int, Integer)) and x == 1:
             return self.element_class(self, x, check)
         if isinstance(x, FiniteWord_class):
