@@ -630,7 +630,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
         from .constructor import HyperellipticCurve
         return HyperellipticCurve(fnew, 0, names=self._names, PP=self._PP)
 
-    def has_odd_degree_model(self):
+    def has_odd_degree_model(self) -> bool:
         r"""
         Return ``True`` if an odd degree model of ``self`` exists over the
         field of definition; ``False`` otherwise.
